@@ -15,20 +15,20 @@ class ValidationResult(Entity):
         bool,
         Field(
             description="True if the validation passed, False otherwise.",
-            example=True,
+            examples=[True],
         ),
     ]
     name: Annotated[
         str,
         Field(
             description="Name of the validation.",
-            example="Neuron spiking validation",
+            examples=["Neuron spiking validation"],
         ),
     ]
     validated_entity_id: Annotated[
         ID,
         Field(
             description="ID of the validated entity.",
-            example="85663316-a7ff-4107-9eb9-236de8868c5c",
+            examples=["85663316-a7ff-4107-9eb9-236de8868c5c"],
         ),
     ]
