@@ -1,4 +1,5 @@
 import uuid
+from typing import NamedTuple
 
 import pytest
 
@@ -7,6 +8,11 @@ from entitysdk.common import ProjectContext
 from tests.unit.util import PROJECT_ID, VIRTUAL_LAB_ID
 
 
+class Clients(NamedTuple):
+    with_context: Client
+    wout_context: Client
+
+
 @pytest.fixture(scope="session")
 def api_url():
     return "http://mock-host:8000"
@@ -46,6 +52,19 @@ def client(project_context, api_url, auth_token):
     return Client(api_url=api_url, project_context=project_context, token_manager=auth_token)
 
 
+@pytest.fixture
+def client_no_context(api_url, auth_token):
+    return Client(api_url=api_url, token_manager=auth_token)
+
+
+@pytest.fixture
+def clients(client, client_no_context):
+    return Clients(
+        with_context=client,
+        wout_context=client_no_context,
+    )
+
+
 @pytest.fixture
 def random_uuid():
     return uuid.uuid4()
