@@ -26,18 +26,16 @@ def test_read_ion_channel_model(client, httpx_mock, auth_token, json_ion_channel
         entity_id=MOCK_UUID,
         entity_type=IonChannelModel,
     )
-    assert entity.model_dump(mode="json") == json_ion_channel_expanded | {"legacy_id": None}
+    assert entity.model_dump(mode="json", exclude_unset=True) == json_ion_channel_expanded
 
 
 def test_register_ion_channel_model(
     client, httpx_mock, auth_token, ion_channel_model, json_ion_channel_expanded
 ):
-    httpx_mock.add_response(
-        method="POST", json=ion_channel_model.model_dump(mode="json") | {"id": str(MOCK_UUID)}
-    )
+    httpx_mock.add_response(method="POST", json=json_ion_channel_expanded | {"id": str(MOCK_UUID)})
     registered = client.register_entity(entity=ion_channel_model)
-    expected_json = json_ion_channel_expanded.copy() | {"id": str(MOCK_UUID)}
-    assert registered.model_dump(mode="json") == expected_json | {"legacy_id": None}
+    expected_json = json_ion_channel_expanded | {"id": str(MOCK_UUID)}
+    assert registered.model_dump(mode="json", exclude_unset=True) == expected_json
 
 
 def test_update_ion_channel_model(
@@ -45,7 +43,7 @@ def test_update_ion_channel_model(
 ):
     httpx_mock.add_response(
         method="PATCH",
-        json=ion_channel_model.model_dump(mode="json") | {"name": "foo"},
+        json=json_ion_channel_expanded | {"name": "foo"},
     )
     updated = client.update_entity(
         entity_id=ion_channel_model.id,
@@ -53,5 +51,5 @@ def test_update_ion_channel_model(
         attrs_or_entity={"name": "foo"},
     )
 
-    expected_json = json_ion_channel_expanded.copy() | {"name": "foo"}
-    assert updated.model_dump(mode="json") == expected_json | {"legacy_id": None}
+    expected_json = json_ion_channel_expanded | {"name": "foo"}
+    assert updated.model_dump(mode="json", exclude_unset=True) == expected_json
